@@ -39,20 +39,23 @@ class PostTeamsCard(BuildToolsTemplate):
         super().__init__(cli_path, cli_descriptions, summary)
 
     def config_parser(self, parser):
+        BUILD_STATUSES = ['STARTED', 'SUCCESS', 'UNSTABLE', 'FAILURE', 'NOT_BUILD', 'ABORTED']
         parser.set_defaults(func=self.run)
         parent_parser = configargparse.ArgParser(add_help=False)
         parent_parser.add('--webhook-url', '-u', required=True, env_var='TEAMS_WEBHOOK_URL',
             help='The Teams "Incoming Webhook" URL for a Teams channel (where messages will be posted).')
-        parent_parser.add('--message', help='Custom messgage to be printed at the top of the card.')
-        parent_parser.add('--file', help='Custom message to be printed at the top of the card, loaded from the file indicated.')
+        parent_parser.add('--message', help='Custom messgage to be printed at the bottom of the card.')
+        parent_parser.add('--file', help='Custom message to be printed at the bottom of the card, loaded from the '
+                                         'file-path indicated by this argument.')
         parent_parser.add('--diff-markdown', action='store_true',
-            help='Wrap the custom message(s) in ```diff\n\{message\}\n``` markdown.')
+            help='Wrap the custom message(s) in ```diff\n{message}\n``` markdown.')
         parent_parser.add('--code-markdown', action='store_true',
-            help='Wrap the custom message(s) in ```\n\{message\}\n``` markdown.')
+            help='Wrap the custom message(s) in ```\n{message}\n``` markdown.')
         parent_parser.add('--clean-ansi-colors', action='store_true',
             help='Clean/remove any ANSI Color codes that are in the provided message/file.')
-        parent_parser.add('--tail', type=int, 
-            help='Only print the last `TAIL` lines of the provided message/file.')    
+        parent_parser.add('--max-size', '--tail', dest='max_size', type=int, default=21000,  # 25kb is the max, so this leaves around => 4kb for all our meta-data...
+            help='''Only print the last `max-comment-size` bytes of the provided message/file (i.e. this has a `tail` 
+                 'behavior by default, to help ensure that the message fits within the Teams message).''')
         subparsers = parser.add_subparsers(title="message-type", dest='message_type',
             description="There are built in 'message types' that can be sent.")
         subparsers.required = True
@@ -60,7 +63,7 @@ class PostTeamsCard(BuildToolsTemplate):
         # Subparser for Build Status Cards
         sp = subparsers.add_parser('build-status', parents=[parent_parser],
             help='Generate a "Jenkins build status" message.')
-        sp.add('status', choices=['STARTED', 'SUCCESS', 'UNSTABLE', 'FAILURE', 'NOT_BUILD', 'ABORTED'],
+        sp.add('status', choices=BUILD_STATUSES,
             help='Provide the build status here (from the provided choices).')
         sp.add('--build-type', default='BUILD', choices=['BUILD', 'DEPLOYMENT'],
             help="The 'type' of the build (from provided choices).")
@@ -97,6 +100,10 @@ class PostTeamsCard(BuildToolsTemplate):
             help='The description of the Bitbucket pull request.')
         sp.add('--playbook-limit', env_var='PLAYBOOK_LIMIT',
             help='A string indicating the PLAYBOOK_LIMIT for this build.')
+        sp.add('--build-status', choices=BUILD_STATUSES,
+            help='Provide the build status (from the provided choices).')
+        sp.add('--jenkins-build-url', env_var='BUILD_URL',
+            help='The URL that links directly to the particular Jenkins build.')
         self.parser = parser
         return parser
 
